==> cdktf-cdktf-provider-google-0.5.133.tar.gz: package/lib/dialogflow-intent.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DialogflowIntentConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the action associated with the intent. Note: The action name must not contain whitespaces.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#action DialogflowIntent#action}
     *
     * @stability stable
     */
    readonly action?: string;
    /**
     * The list of platforms for which the first responses will be copied from the messages in PLATFORM_UNSPECIFIED (i.e. default platform). Possible values: ["FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "GOOGLE_HANGOUTS"].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#default_response_platforms DialogflowIntent#default_response_platforms}
     *
     * @stability stable
     */
    readonly defaultResponsePlatforms?: string[];
    /**
     * The name of this intent to be displayed on the console.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#display_name DialogflowIntent#display_name}
     *
     * @stability stable
     */
    readonly displayName: string;
    /**
     * The collection of event names that trigger the intent.
     *
     * If the collection of input contexts is not empty, all of
     * the contexts must be present in the active user session for an event to trigger this intent. See the
     * [events reference](https://cloud.google.com/dialogflow/docs/events-overview) for more details.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#events DialogflowIntent#events}
     *
     * @stability stable
     */
    readonly events?: string[];
    /**
     * The list of context names required for this intent to be triggered. Format: projects/<Project ID>/agent/sessions/-/contexts/<Context ID>.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#input_context_names DialogflowIntent#input_context_names}
     *
     * @stability stable
     */
    readonly inputContextNames?: string[];
    /**
     * Indicates whether this is a fallback intent.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#is_fallback DialogflowIntent#is_fallback}
     *
     * @stability stable
     */
    readonly isFallback?: boolean | cdktf.IResolvable;
    /**
     * Indicates whether Machine Learning is disabled for the intent.
     *
     * Note: If mlDisabled setting is set to true, then this intent is not taken into account during inference in ML
     * ONLY match mode. Also, auto-markup in the UI is turned off.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#ml_disabled DialogflowIntent#ml_disabled}
     *
     * @stability stable
     */
    readonly mlDisabled?: boolean | cdktf.IResolvable;
    /**
     * The unique identifier of the parent intent in the chain of followup intents. Format: projects/<Project ID>/agent/intents/<Intent ID>.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#parent_followup_intent_name DialogflowIntent#parent_followup_intent_name}
     *
     * @stability stable
     */
    readonly parentFollowupIntentName?: string;
    /**
     * The priority of this intent.
     *
     * Higher numbers represent higher priorities.
     * - If the supplied value is unspecified or 0, the service translates the value to 500,000, which corresponds
     * to the Normal priority in the console.
     * - If the supplied value is negative, the intent is ignored in runtime detect intent requests.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#priority DialogflowIntent#priority}
     *
     * @stability stable
     */
    readonly priority?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#project DialogflowIntent#project}.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Indicates whether to delete all contexts in the current session when this intent is matched.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#reset_contexts DialogflowIntent#reset_contexts}
     *
     * @stability stable
     */
    readonly resetContexts?: boolean | cdktf.IResolvable;
    /**
     * Indicates whether webhooks are enabled for the intent.
     *
     * WEBHOOK_STATE_ENABLED: Webhook is enabled in the agent and in the intent.
     * WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING: Webhook is enabled in the agent and in the intent. Also, each slot
     * filling prompt is forwarded to the webhook. Possible values: ["WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"]
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#webhook_state DialogflowIntent#webhook_state}
     *
     * @stability stable
     */
    readonly webhookState?: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#timeouts DialogflowIntent#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DialogflowIntentTimeouts;
}
/**
 * @stability stable
 */
export declare class DialogflowIntentFollowupIntentInfo extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get followupIntentName(): string;
    /**
     * @stability stable
     */
    get parentFollowupIntentName(): string;
}
/**
 * @stability stable
 */
export interface DialogflowIntentTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#create DialogflowIntent#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#delete DialogflowIntent#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#update DialogflowIntent#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function dialogflowIntentTimeoutsToTerraform(struct?: DialogflowIntentTimeoutsOutputReference | DialogflowIntentTimeouts): any;
/**
 * @stability stable
 */
export declare class DialogflowIntentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DialogflowIntentTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DialogflowIntentTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent google_dialogflow_intent}.
 *
 * @stability stable
 */
export declare class DialogflowIntent extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent google_dialogflow_intent} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DialogflowIntentConfig);
    private _action?;
    /**
     * @stability stable
     */
    get action(): string;
    /**
     * @stability stable
     */
    set action(value: string);
    /**
     * @stability stable
     */
    resetAction(): void;
    /**
     * @stability stable
     */
    get actionInput(): string | undefined;
    private _defaultResponsePlatforms?;
    /**
     * @stability stable
     */
    get defaultResponsePlatforms(): string[];
    /**
     * @stability stable
     */
    set defaultResponsePlatforms(value: string[]);
    /**
     * @stability stable
     */
    resetDefaultResponsePlatforms(): void;
    /**
     * @stability stable
     */
    get defaultResponsePlatformsInput(): string[] | undefined;
    private _displayName?;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    get displayNameInput(): string | undefined;
    private _events?;
    /**
     * @stability stable
     */
    get events(): string[];
    /**
     * @stability stable
     */
    set events(value: string[]);
    /**
     * @stability stable
     */
    resetEvents(): void;
    /**
     * @stability stable
     */
    get eventsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    followupIntentInfo(index: string): DialogflowIntentFollowupIntentInfo;
    /**
     * @stability stable
     */
    get id(): string;
    private _inputContextNames?;
    /**
     * @stability stable
     */
    get inputContextNames(): string[];
    /**
     * @stability stable
     */
    set inputContextNames(value: string[]);
    /**
     * @stability stable
     */
    resetInputContextNames(): void;
    /**
     * @stability stable
     */
    get inputContextNamesInput(): string[] | undefined;
    private _isFallback?;
    /**
     * @stability stable
     */
    get isFallback(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isFallback(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsFallback(): void;
    /**
     * @stability stable
     */
    get isFallbackInput(): boolean | cdktf.IResolvable | undefined;
    private _mlDisabled?;
    /**
     * @stability stable
     */
    get mlDisabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mlDisabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMlDisabled(): void;
    /**
     * @stability stable
     */
    get mlDisabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get name(): string;
    private _parentFollowupIntentName?;
    /**
     * @stability stable
     */
    get parentFollowupIntentName(): string;
    /**
     * @stability stable
     */
    set parentFollowupIntentName(value: string);
    /**
     * @stability stable
     */
    resetParentFollowupIntentName(): void;
    /**
     * @stability stable
     */
    get parentFollowupIntentNameInput(): string | undefined;
    private _priority?;
    /**
     * @stability stable
     */
    get priority(): number;
    /**
     * @stability stable
     */
    set priority(value: number);
    /**
     * @stability stable
     */
    resetPriority(): void;
    /**
     * @stability stable
     */
    get priorityInput(): number | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _resetContexts?;
    /**
     * @stability stable
     */
    get resetContexts(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set resetContexts(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetResetContexts(): void;
    /**
     * @stability stable
     */
    get resetContextsInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get rootFollowupIntentName(): string;
    private _webhookState?;
    /**
     * @stability stable
     */
    get webhookState(): string;
    /**
     * @stability stable
     */
    set webhookState(value: string);
    /**
     * @stability stable
     */
    resetWebhookState(): void;
    /**
     * @stability stable
     */
    get webhookStateInput(): string | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DialogflowIntentTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DialogflowIntentTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DialogflowIntentTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.2.tar.gz: package/lib/dialogflow-intent.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DialogflowIntentConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the action associated with the intent. Note: The action name must not contain whitespaces.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#action DialogflowIntent#action}
     *
     * @stability stable
     */
    readonly action?: string;
    /**
     * The list of platforms for which the first responses will be copied from the messages in PLATFORM_UNSPECIFIED (i.e. default platform). Possible values: ["FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "GOOGLE_HANGOUTS"].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#default_response_platforms DialogflowIntent#default_response_platforms}
     *
     * @stability stable
     */
    readonly defaultResponsePlatforms?: string[];
    /**
     * The name of this intent to be displayed on the console.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#display_name DialogflowIntent#display_name}
     *
     * @stability stable
     */
    readonly displayName: string;
    /**
     * The collection of event names that trigger the intent.
     *
     * If the collection of input contexts is not empty, all of
     * the contexts must be present in the active user session for an event to trigger this intent. See the
     * [events reference](https://cloud.google.com/dialogflow/docs/events-overview) for more details.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#events DialogflowIntent#events}
     *
     * @stability stable
     */
    readonly events?: string[];
    /**
     * The list of context names required for this intent to be triggered. Format: projects/<Project ID>/agent/sessions/-/contexts/<Context ID>.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#input_context_names DialogflowIntent#input_context_names}
     *
     * @stability stable
     */
    readonly inputContextNames?: string[];
    /**
     * Indicates whether this is a fallback intent.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#is_fallback DialogflowIntent#is_fallback}
     *
     * @stability stable
     */
    readonly isFallback?: boolean | cdktf.IResolvable;
    /**
     * Indicates whether Machine Learning is disabled for the intent.
     *
     * Note: If mlDisabled setting is set to true, then this intent is not taken into account during inference in ML
     * ONLY match mode. Also, auto-markup in the UI is turned off.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#ml_disabled DialogflowIntent#ml_disabled}
     *
     * @stability stable
     */
    readonly mlDisabled?: boolean | cdktf.IResolvable;
    /**
     * The unique identifier of the parent intent in the chain of followup intents. Format: projects/<Project ID>/agent/intents/<Intent ID>.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#parent_followup_intent_name DialogflowIntent#parent_followup_intent_name}
     *
     * @stability stable
     */
    readonly parentFollowupIntentName?: string;
    /**
     * The priority of this intent.
     *
     * Higher numbers represent higher priorities.
     * - If the supplied value is unspecified or 0, the service translates the value to 500,000, which corresponds
     * to the Normal priority in the console.
     * - If the supplied value is negative, the intent is ignored in runtime detect intent requests.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#priority DialogflowIntent#priority}
     *
     * @stability stable
     */
    readonly priority?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#project DialogflowIntent#project}.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Indicates whether to delete all contexts in the current session when this intent is matched.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#reset_contexts DialogflowIntent#reset_contexts}
     *
     * @stability stable
     */
    readonly resetContexts?: boolean | cdktf.IResolvable;
    /**
     * Indicates whether webhooks are enabled for the intent.
     *
     * WEBHOOK_STATE_ENABLED: Webhook is enabled in the agent and in the intent.
     * WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING: Webhook is enabled in the agent and in the intent. Also, each slot
     * filling prompt is forwarded to the webhook. Possible values: ["WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"]
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#webhook_state DialogflowIntent#webhook_state}
     *
     * @stability stable
     */
    readonly webhookState?: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#timeouts DialogflowIntent#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DialogflowIntentTimeouts;
}
/**
 * @stability stable
 */
export declare class DialogflowIntentFollowupIntentInfo extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get followupIntentName(): string;
    /**
     * @stability stable
     */
    get parentFollowupIntentName(): string;
}
/**
 * @stability stable
 */
export interface DialogflowIntentTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#create DialogflowIntent#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#delete DialogflowIntent#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent#update DialogflowIntent#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function dialogflowIntentTimeoutsToTerraform(struct?: DialogflowIntentTimeoutsOutputReference | DialogflowIntentTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class DialogflowIntentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DialogflowIntentTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DialogflowIntentTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent google_dialogflow_intent}.
 *
 * @stability stable
 */
export declare class DialogflowIntent extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/dialogflow_intent google_dialogflow_intent} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DialogflowIntentConfig);
    private _action?;
    /**
     * @stability stable
     */
    get action(): string;
    /**
     * @stability stable
     */
    set action(value: string);
    /**
     * @stability stable
     */
    resetAction(): void;
    /**
     * @stability stable
     */
    get actionInput(): string | undefined;
    private _defaultResponsePlatforms?;
    /**
     * @stability stable
     */
    get defaultResponsePlatforms(): string[];
    /**
     * @stability stable
     */
    set defaultResponsePlatforms(value: string[]);
    /**
     * @stability stable
     */
    resetDefaultResponsePlatforms(): void;
    /**
     * @stability stable
     */
    get defaultResponsePlatformsInput(): string[] | undefined;
    private _displayName?;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    get displayNameInput(): string | undefined;
    private _events?;
    /**
     * @stability stable
     */
    get events(): string[];
    /**
     * @stability stable
     */
    set events(value: string[]);
    /**
     * @stability stable
     */
    resetEvents(): void;
    /**
     * @stability stable
     */
    get eventsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    followupIntentInfo(index: string): DialogflowIntentFollowupIntentInfo;
    /**
     * @stability stable
     */
    get id(): string;
    private _inputContextNames?;
    /**
     * @stability stable
     */
    get inputContextNames(): string[];
    /**
     * @stability stable
     */
    set inputContextNames(value: string[]);
    /**
     * @stability stable
     */
    resetInputContextNames(): void;
    /**
     * @stability stable
     */
    get inputContextNamesInput(): string[] | undefined;
    private _isFallback?;
    /**
     * @stability stable
     */
    get isFallback(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isFallback(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsFallback(): void;
    /**
     * @stability stable
     */
    get isFallbackInput(): boolean | cdktf.IResolvable | undefined;
    private _mlDisabled?;
    /**
     * @stability stable
     */
    get mlDisabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mlDisabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMlDisabled(): void;
    /**
     * @stability stable
     */
    get mlDisabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get name(): string;
    private _parentFollowupIntentName?;
    /**
     * @stability stable
     */
    get parentFollowupIntentName(): string;
    /**
     * @stability stable
     */
    set parentFollowupIntentName(value: string);
    /**
     * @stability stable
     */
    resetParentFollowupIntentName(): void;
    /**
     * @stability stable
     */
    get parentFollowupIntentNameInput(): string | undefined;
    private _priority?;
    /**
     * @stability stable
     */
    get priority(): number;
    /**
     * @stability stable
     */
    set priority(value: number);
    /**
     * @stability stable
     */
    resetPriority(): void;
    /**
     * @stability stable
     */
    get priorityInput(): number | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _resetContexts?;
    /**
     * @stability stable
     */
    get resetContexts(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set resetContexts(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetResetContexts(): void;
    /**
     * @stability stable
     */
    get resetContextsInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get rootFollowupIntentName(): string;
    private _webhookState?;
    /**
     * @stability stable
     */
    get webhookState(): string;
    /**
     * @stability stable
     */
    set webhookState(value: string);
    /**
     * @stability stable
     */
    resetWebhookState(): void;
    /**
     * @stability stable
     */
    get webhookStateInput(): string | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DialogflowIntentTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DialogflowIntentTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DialogflowIntentTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
